#[non_exhaustive]pub struct CreateQev2IdcApplicationInput {
pub idc_instance_arn: Option<String>,
pub qev2_idc_application_name: Option<String>,
pub idc_display_name: Option<String>,
pub tags: Option<Vec<Tag>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.idc_instance_arn: Option<String>The Amazon Resource Name (ARN) of the IAM Identity Center instance used to create the Amazon Redshift Query Editor (QEV2) managed application.
qev2_idc_application_name: Option<String>The name of the Amazon Redshift Query Editor (QEV2) application in IAM Identity Center.
idc_display_name: Option<String>The display name for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application. It appears in the console.
A list of tags to associate with the application. Tags are key-value pairs that you can use to organize and identify your resources.
Implementations
Sourceimpl CreateQev2IdcApplicationInput
impl CreateQev2IdcApplicationInput
Sourcepub fn idc_instance_arn(&self) -> Option<&str>
pub fn idc_instance_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM Identity Center instance used to create the Amazon Redshift Query Editor (QEV2) managed application.
Sourcepub fn qev2_idc_application_name(&self) -> Option<&str>
pub fn qev2_idc_application_name(&self) -> Option<&str>
The name of the Amazon Redshift Query Editor (QEV2) application in IAM Identity Center.
Sourcepub fn idc_display_name(&self) -> Option<&str>
pub fn idc_display_name(&self) -> Option<&str>
The display name for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application. It appears in the console.
A list of tags to associate with the application. Tags are key-value pairs that you can use to organize and identify your resources.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl CreateQev2IdcApplicationInput
impl CreateQev2IdcApplicationInput
Sourcepub fn builder() -> CreateQev2IdcApplicationInputBuilder
pub fn builder() -> CreateQev2IdcApplicationInputBuilder
Creates a new builder-style object to manufacture CreateQev2IdcApplicationInput.