pub struct DisableLoggingFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DisableLogging.
Stops logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster.
Implementations
Sourceimpl DisableLoggingFluentBuilder
impl DisableLoggingFluentBuilder
Sourcepub fn as_input(&self) -> &DisableLoggingInputBuilder
pub fn as_input(&self) -> &DisableLoggingInputBuilder
Access the DisableLogging as a reference.
Sourcepub async fn send(
self,
) -> Result<DisableLoggingOutput, SdkError<DisableLoggingError, HttpResponse>>
pub async fn send( self, ) -> Result<DisableLoggingOutput, SdkError<DisableLoggingError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DisableLoggingOutput, DisableLoggingError, Self>
pub fn customize( self, ) -> CustomizableOperation<DisableLoggingOutput, DisableLoggingError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn cluster_identifier(self, input: impl Into<String>) -> Self
pub fn cluster_identifier(self, input: impl Into<String>) -> Self
The identifier of the cluster on which logging is to be stopped.
Example: examplecluster
Sourcepub fn set_cluster_identifier(self, input: Option<String>) -> Self
pub fn set_cluster_identifier(self, input: Option<String>) -> Self
The identifier of the cluster on which logging is to be stopped.
Example: examplecluster
Sourcepub fn get_cluster_identifier(&self) -> &Option<String>
pub fn get_cluster_identifier(&self) -> &Option<String>
The identifier of the cluster on which logging is to be stopped.
Example: examplecluster
Sourcepub fn log_destination_type(self, input: LogDestinationType) -> Self
pub fn log_destination_type(self, input: LogDestinationType) -> Self
The log destination type. An enum with possible values of s3, cloudwatch, and s3table. When set to s3table, stops system table publishing. When omitted, the operation disables audit logging.
Sourcepub fn set_log_destination_type(self, input: Option<LogDestinationType>) -> Self
pub fn set_log_destination_type(self, input: Option<LogDestinationType>) -> Self
The log destination type. An enum with possible values of s3, cloudwatch, and s3table. When set to s3table, stops system table publishing. When omitted, the operation disables audit logging.
Sourcepub fn get_log_destination_type(&self) -> &Option<LogDestinationType>
pub fn get_log_destination_type(&self) -> &Option<LogDestinationType>
The log destination type. An enum with possible values of s3, cloudwatch, and s3table. When set to s3table, stops system table publishing. When omitted, the operation disables audit logging.
Sourcepub fn log_exports(self, input: impl Into<String>) -> Self
pub fn log_exports(self, input: impl Into<String>) -> Self
Appends an item to LogExports.
To override the contents of this collection use set_log_exports.
The collection of log types to stop exporting. When LogDestinationType is s3table, the values are the names of the system tables to stop publishing. Omitting this parameter or passing all stops publishing all system tables.
Sourcepub fn set_log_exports(self, input: Option<Vec<String>>) -> Self
pub fn set_log_exports(self, input: Option<Vec<String>>) -> Self
The collection of log types to stop exporting. When LogDestinationType is s3table, the values are the names of the system tables to stop publishing. Omitting this parameter or passing all stops publishing all system tables.
Sourcepub fn get_log_exports(&self) -> &Option<Vec<String>>
pub fn get_log_exports(&self) -> &Option<Vec<String>>
The collection of log types to stop exporting. When LogDestinationType is s3table, the values are the names of the system tables to stop publishing. Omitting this parameter or passing all stops publishing all system tables.