#[non_exhaustive]pub struct EnableLoggingInputBuilder { /* private fields */ }Expand description
A builder for EnableLoggingInput.
Implementations
Sourceimpl EnableLoggingInputBuilder
impl EnableLoggingInputBuilder
Sourcepub fn cluster_identifier(self, input: impl Into<String>) -> Self
pub fn cluster_identifier(self, input: impl Into<String>) -> Self
The identifier of the cluster on which logging is to be started.
Example: examplecluster
Sourcepub fn set_cluster_identifier(self, input: Option<String>) -> Self
pub fn set_cluster_identifier(self, input: Option<String>) -> Self
The identifier of the cluster on which logging is to be started.
Example: examplecluster
Sourcepub fn get_cluster_identifier(&self) -> &Option<String>
pub fn get_cluster_identifier(&self) -> &Option<String>
The identifier of the cluster on which logging is to be started.
Example: examplecluster
Sourcepub fn bucket_name(self, input: impl Into<String>) -> Self
pub fn bucket_name(self, input: impl Into<String>) -> Self
The name of an existing S3 bucket where the log files are to be stored.
Constraints:
-
Must be in the same region as the cluster
-
The cluster must have read bucket and put object permissions
Sourcepub fn set_bucket_name(self, input: Option<String>) -> Self
pub fn set_bucket_name(self, input: Option<String>) -> Self
The name of an existing S3 bucket where the log files are to be stored.
Constraints:
-
Must be in the same region as the cluster
-
The cluster must have read bucket and put object permissions
Sourcepub fn get_bucket_name(&self) -> &Option<String>
pub fn get_bucket_name(&self) -> &Option<String>
The name of an existing S3 bucket where the log files are to be stored.
Constraints:
-
Must be in the same region as the cluster
-
The cluster must have read bucket and put object permissions
Sourcepub fn s3_key_prefix(self, input: impl Into<String>) -> Self
pub fn s3_key_prefix(self, input: impl Into<String>) -> Self
The prefix applied to the log file names.
Valid characters are any letter from any language, any whitespace character, any numeric character, and the following characters: underscore (_), period (.), colon (:), slash (/), equal (=), plus (+), backslash (\), hyphen (-), at symbol (@).
Sourcepub fn set_s3_key_prefix(self, input: Option<String>) -> Self
pub fn set_s3_key_prefix(self, input: Option<String>) -> Self
The prefix applied to the log file names.
Valid characters are any letter from any language, any whitespace character, any numeric character, and the following characters: underscore (_), period (.), colon (:), slash (/), equal (=), plus (+), backslash (\), hyphen (-), at symbol (@).
Sourcepub fn get_s3_key_prefix(&self) -> &Option<String>
pub fn get_s3_key_prefix(&self) -> &Option<String>
The prefix applied to the log file names.
Valid characters are any letter from any language, any whitespace character, any numeric character, and the following characters: underscore (_), period (.), colon (:), slash (/), equal (=), plus (+), backslash (\), hyphen (-), at symbol (@).
Sourcepub fn log_destination_type(self, input: LogDestinationType) -> Self
pub fn log_destination_type(self, input: LogDestinationType) -> Self
The log destination type. An enum with possible values of s3, cloudwatch, and s3table.
Sourcepub fn set_log_destination_type(self, input: Option<LogDestinationType>) -> Self
pub fn set_log_destination_type(self, input: Option<LogDestinationType>) -> Self
The log destination type. An enum with possible values of s3, cloudwatch, and s3table.
Sourcepub fn get_log_destination_type(&self) -> &Option<LogDestinationType>
pub fn get_log_destination_type(&self) -> &Option<LogDestinationType>
The log destination type. An enum with possible values of s3, cloudwatch, and s3table.
Sourcepub fn log_exports(self, input: impl Into<String>) -> Self
pub fn log_exports(self, input: impl Into<String>) -> Self
Appends an item to log_exports.
To override the contents of this collection use set_log_exports.
The collection of exported log types. When LogDestinationType is s3 or cloudwatch, possible values are connectionlog, useractivitylog, and userlog. When LogDestinationType is s3table, the values are the names of the system tables to publish. Omitting this parameter, passing an empty list, or including the value all publishes all current and future system tables.
Sourcepub fn set_log_exports(self, input: Option<Vec<String>>) -> Self
pub fn set_log_exports(self, input: Option<Vec<String>>) -> Self
The collection of exported log types. When LogDestinationType is s3 or cloudwatch, possible values are connectionlog, useractivitylog, and userlog. When LogDestinationType is s3table, the values are the names of the system tables to publish. Omitting this parameter, passing an empty list, or including the value all publishes all current and future system tables.
Sourcepub fn get_log_exports(&self) -> &Option<Vec<String>>
pub fn get_log_exports(&self) -> &Option<Vec<String>>
The collection of exported log types. When LogDestinationType is s3 or cloudwatch, possible values are connectionlog, useractivitylog, and userlog. When LogDestinationType is s3table, the values are the names of the system tables to publish. Omitting this parameter, passing an empty list, or including the value all publishes all current and future system tables.
Sourcepub fn s3_table_kms_key_id(self, input: impl Into<String>) -> Self
pub fn s3_table_kms_key_id(self, input: impl Into<String>) -> Self
The identifier of a customer managed KMS key used to encrypt the S3 tables. This parameter is valid only when LogDestinationType is s3table.
Sourcepub fn set_s3_table_kms_key_id(self, input: Option<String>) -> Self
pub fn set_s3_table_kms_key_id(self, input: Option<String>) -> Self
The identifier of a customer managed KMS key used to encrypt the S3 tables. This parameter is valid only when LogDestinationType is s3table.
Sourcepub fn get_s3_table_kms_key_id(&self) -> &Option<String>
pub fn get_s3_table_kms_key_id(&self) -> &Option<String>
The identifier of a customer managed KMS key used to encrypt the S3 tables. This parameter is valid only when LogDestinationType is s3table.
Sourcepub fn s3_table_granularity(self, input: impl Into<String>) -> Self
pub fn s3_table_granularity(self, input: impl Into<String>) -> Self
The scope of system table publishing. Valid values are cluster and account. A value of cluster scopes publishing to the individual cluster. A value of account scopes publishing to the Amazon Web Services account. This parameter is valid only when LogDestinationType is s3table.
Sourcepub fn set_s3_table_granularity(self, input: Option<String>) -> Self
pub fn set_s3_table_granularity(self, input: Option<String>) -> Self
The scope of system table publishing. Valid values are cluster and account. A value of cluster scopes publishing to the individual cluster. A value of account scopes publishing to the Amazon Web Services account. This parameter is valid only when LogDestinationType is s3table.
Sourcepub fn get_s3_table_granularity(&self) -> &Option<String>
pub fn get_s3_table_granularity(&self) -> &Option<String>
The scope of system table publishing. Valid values are cluster and account. A value of cluster scopes publishing to the individual cluster. A value of account scopes publishing to the Amazon Web Services account. This parameter is valid only when LogDestinationType is s3table.
Sourcepub fn build(self) -> Result<EnableLoggingInput, BuildError>
pub fn build(self) -> Result<EnableLoggingInput, BuildError>
Consumes the builder and constructs a EnableLoggingInput.
Sourceimpl EnableLoggingInputBuilder
impl EnableLoggingInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<EnableLoggingOutput, SdkError<EnableLoggingError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<EnableLoggingOutput, SdkError<EnableLoggingError, HttpResponse>>
Sends a request with this input using the given client.