#[non_exhaustive]pub struct Qev2IdcApplication {
pub idc_instance_arn: Option<String>,
pub qev2_idc_application_name: Option<String>,
pub qev2_idc_application_arn: Option<String>,
pub idc_managed_application_arn: Option<String>,
pub idc_onboard_status: Option<String>,
pub idc_display_name: Option<String>,
pub tags: Option<Vec<Tag>>,
}Expand description
Contains configuration and status information for an Amazon Redshift Query Editor (QEV2) application that is registered with IAM Identity Center.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.idc_instance_arn: Option<String>The Amazon Resource Name (ARN) for the IAM Identity Center instance that the Amazon Redshift Query Editor (QEV2) application integrates with.
qev2_idc_application_name: Option<String>The name of the Amazon Redshift Query Editor (QEV2) application in IAM Identity Center.
qev2_idc_application_arn: Option<String>The Amazon Resource Name (ARN) for the Amazon Redshift Query Editor (QEV2) application that integrates with IAM Identity Center.
idc_managed_application_arn: Option<String>The Amazon Resource Name (ARN) for the Amazon Redshift Query Editor (QEV2) IAM Identity Center managed application.
idc_onboard_status: Option<String>The onboarding status for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application.
idc_display_name: Option<String>The display name for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application. It appears in the console.
A list of tags associated with the application. Tags are key-value pairs that you can use to organize and identify your resources.
Implementations
Sourceimpl Qev2IdcApplication
impl Qev2IdcApplication
Sourcepub fn idc_instance_arn(&self) -> Option<&str>
pub fn idc_instance_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) for the IAM Identity Center instance that the Amazon Redshift Query Editor (QEV2) application integrates with.
Sourcepub fn qev2_idc_application_name(&self) -> Option<&str>
pub fn qev2_idc_application_name(&self) -> Option<&str>
The name of the Amazon Redshift Query Editor (QEV2) application in IAM Identity Center.
Sourcepub fn qev2_idc_application_arn(&self) -> Option<&str>
pub fn qev2_idc_application_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) for the Amazon Redshift Query Editor (QEV2) application that integrates with IAM Identity Center.
Sourcepub fn idc_managed_application_arn(&self) -> Option<&str>
pub fn idc_managed_application_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) for the Amazon Redshift Query Editor (QEV2) IAM Identity Center managed application.
Sourcepub fn idc_onboard_status(&self) -> Option<&str>
pub fn idc_onboard_status(&self) -> Option<&str>
The onboarding status for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application.
Sourcepub fn idc_display_name(&self) -> Option<&str>
pub fn idc_display_name(&self) -> Option<&str>
The display name for the Amazon Redshift Query Editor (QEV2) IAM Identity Center application. It appears in the console.
A list of tags associated with the application. Tags are key-value pairs that you can use to organize and identify your resources.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl Qev2IdcApplication
impl Qev2IdcApplication
Sourcepub fn builder() -> Qev2IdcApplicationBuilder
pub fn builder() -> Qev2IdcApplicationBuilder
Creates a new builder-style object to manufacture Qev2IdcApplication.